# RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**property_type** | **str** |  | [optional] 
**average_rent** | **float** |  | [optional] [default to ]
**median_rent** | **float** |  | [optional] [default to ]
**min_rent** | **float** |  | [optional] [default to ]
**max_rent** | **float** |  | [optional] [default to ]
**average_rent_per_square_foot** | **float** |  | [optional] [default to ]
**median_rent_per_square_foot** | **float** |  | [optional] [default to ]
**min_rent_per_square_foot** | **float** |  | [optional] [default to ]
**max_rent_per_square_foot** | **float** |  | [optional] [default to ]
**average_square_footage** | **float** |  | [optional] [default to ]
**median_square_footage** | **float** |  | [optional] [default to ]
**min_square_footage** | **float** |  | [optional] [default to ]
**max_square_footage** | **float** |  | [optional] [default to ]
**average_days_on_market** | **float** |  | [optional] [default to ]
**median_days_on_market** | **float** |  | [optional] [default to ]
**min_days_on_market** | **float** |  | [optional] [default to ]
**max_days_on_market** | **float** |  | [optional] [default to ]
**new_listings** | **float** |  | [optional] [default to ]
**total_listings** | **float** |  | [optional] [default to ]

## Example

```python
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202507_data_by_property_type_inner import RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner

# TODO update the JSON string below
json = "{}"
# create an instance of RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner from a JSON string
rentcast_market_statistics200_response_rental_data_history202507_data_by_property_type_inner_instance = RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner.from_json(json)
# print the JSON string representation of the object
print(RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner.to_json())

# convert the object into a dict
rentcast_market_statistics200_response_rental_data_history202507_data_by_property_type_inner_dict = rentcast_market_statistics200_response_rental_data_history202507_data_by_property_type_inner_instance.to_dict()
# create an instance of RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner from a dict
rentcast_market_statistics200_response_rental_data_history202507_data_by_property_type_inner_from_dict = RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner.from_dict(rentcast_market_statistics200_response_rental_data_history202507_data_by_property_type_inner_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


